From af010d490e57540cd2351e237209db27636d3ded Mon Sep 17 00:00:00 2001
From: Karlheinz Wohlmuth <kwohl@myopera.com>
Date: Wed, 16 May 2012 00:01:45 +0200
Subject: [PATCH] Growl: remove the item-change callback

---
 modules/notify/growl.m |   62 +++++++----------------------------------------
 1 files changed, 10 insertions(+), 52 deletions(-)

diff --git a/modules/notify/growl.m b/modules/notify/growl.m
index 028d9ed..20d742a 100644
--- a/modules/notify/growl.m
+++ b/modules/notify/growl.m
@@ -63,7 +63,7 @@
 
 
 /*****************************************************************************
- * intf_sys_t, VLCGrowlDelegate
+ * VLCGrowlDelegate
  *****************************************************************************/
 @interface VLCGrowlDelegate : NSObject <GrowlApplicationBridgeDelegate>
 {
@@ -77,13 +77,6 @@
                        artUrl: (const char *)psz_arturl;
 @end
 
-struct intf_sys_t
-{
-    VLCGrowlDelegate *o_growl_delegate;
-    int             i_id;
-    int             i_item_changes;
-};
-
 /*****************************************************************************
  * Local prototypes
  *****************************************************************************/
@@ -113,21 +106,17 @@ static int Open( vlc_object_t *p_this )
 {
     intf_thread_t *p_intf = (intf_thread_t *)p_this;
     playlist_t *p_playlist;
-    intf_sys_t    *p_sys;
-
-    p_sys = p_intf->p_sys = calloc( 1, sizeof(intf_sys_t) );
-    if( !p_sys )
-        return VLC_ENOMEM;
+    VLCGrowlDelegate *o_growl_delegate;
 
-    p_sys->o_growl_delegate = [[VLCGrowlDelegate alloc] init];
-    if( !p_sys->o_growl_delegate )
+    o_growl_delegate = [[VLCGrowlDelegate alloc] init];
+    if( !o_growl_delegate )
       return VLC_ENOMEM;
 
+    p_intf->p_sys = (void *)o_growl_delegate;
     p_playlist = pl_Get( p_intf );
-    var_AddCallback( p_playlist, "item-change", ItemChange, p_intf );
     var_AddCallback( p_playlist, "item-current", ItemChange, p_intf );
 
-    [p_sys->o_growl_delegate registerToGrowl];
+    [o_growl_delegate registerToGrowl];
     return VLC_SUCCESS;
 }
 
@@ -138,13 +127,10 @@ static void Close( vlc_object_t *p_this )
 {
     intf_thread_t *p_intf = (intf_thread_t *)p_this;
     playlist_t *p_playlist = pl_Get( p_this );
-    intf_sys_t *p_sys = p_intf->p_sys;
+    VLCGrowlDelegate *o_growl_delegate = (VLCGrowlDelegate *)p_intf->p_sys;
 
-    var_DelCallback( p_playlist, "item-change", ItemChange, p_intf );
     var_DelCallback( p_playlist, "item-current", ItemChange, p_intf );
-
-    [p_sys->o_growl_delegate release];
-    free( p_sys );
+    [o_growl_delegate release];
 }
 
 /*****************************************************************************
@@ -154,6 +140,7 @@ static int ItemChange( vlc_object_t *p_this, const char *psz_var,
                       vlc_value_t oldval, vlc_value_t newval, void *param )
 {
     VLC_UNUSED(oldval);
+    VLC_UNUSED(psz_var);
 
     intf_thread_t *p_intf = (intf_thread_t *)param;
     char *psz_tmp           = NULL;
@@ -161,35 +148,6 @@ static int ItemChange( vlc_object_t *p_this, const char *psz_var,
     char *psz_artist        = NULL;
     char *psz_album         = NULL;
     input_item_t *p_item = newval.p_address;
-
-    bool b_is_item_current = !strcmp( "item-current", psz_var );
-
-    /* Don't update each time an item has been preparsed */
-    if( b_is_item_current )
-    { /* stores the current input item id */
-        p_intf->p_sys->i_id = p_item->i_id;
-        p_intf->p_sys->i_item_changes = 0;
-        return VLC_SUCCESS;
-    }
-    /* ignore items which weren't pre-parsed yet */
-    else if( !input_item_IsPreparsed(p_item) )
-        return VLC_SUCCESS;
-    else
-    {
-        if( p_item->i_id != p_intf->p_sys->i_id ) { /* "item-change" */
-            p_intf->p_sys->i_item_changes = 0;
-            return VLC_SUCCESS;
-        }
-        /* Some variable bitrate inputs call "item-change" callbacks each time
-         * their length is updated, that is several times per second.
-         * We'll limit the number of changes to 1 per input. */
-        if( p_intf->p_sys->i_item_changes > 0 )
-            return VLC_SUCCESS;
-
-        p_intf->p_sys->i_item_changes++;
-    }
-
-
     input_thread_t *p_input = playlist_CurrentInput( (playlist_t*)p_this );
 
     if( !p_input ) return VLC_SUCCESS;
@@ -244,7 +202,7 @@ static int ItemChange( vlc_object_t *p_this, const char *psz_var,
         psz_arturl = psz;
     }
 
-    [p_intf->p_sys->o_growl_delegate notifyWithDescription: psz_tmp artUrl: psz_arturl];
+    [(VLCGrowlDelegate *)p_intf->p_sys notifyWithDescription: psz_tmp artUrl: psz_arturl];
 
     free( psz_title );
     free( psz_artist );
-- 
1.7.7.5 (Apple Git-26)

